@@ -163,6 +163,18 @@ def clean(args):
     perform.execute("/usr/bin/apt-get clean", root=True)
 
 
+def commands(args):
+    """Display all wajig commands"""
+    for name, value in sorted(globals().items()):
+        if inspect.isfunction(value):
+            summary = value.__doc__.split('\n')[0]
+            if args.pattern:
+                if args.pattern not in summary and \
+                   args.pattern not in name:
+                    continue
+            print(f"{name:<18} {summary}")
+
+
 def contents(args):
     """List the contents of a package file (.deb)"""
     perform.execute("dpkg --contents " + args.debfile)
@@ -480,18 +492,6 @@ def listalternatives(args):
     perform.execute(command)
 
 
-def listcommands(args):
-    """Display all wajig commands"""
-    for name, value in sorted(globals().items()):
-        if inspect.isfunction(value):
-            summary = value.__doc__.split('\n')[0]
-            if args.pattern:
-                if args.pattern not in summary and \
-                   args.pattern not in name:
-                    continue
-            print(f"{name:<18} {summary}")
-
-
 def listdaemons(args):
     """List the daemons that wajig can start, stop, restart, or reload"""
     util.requires_package("chkconfig")
@@ -722,11 +722,18 @@ def reboot(args):
     """Check if a reboot is required"""
 
     REBOOT = "/var/run/reboot-required"
-    command = f"test -f {REBOOT}"
-    result = perform.execute(command)
+    PKGS = "/var/run/reboot-required.pkgs"
+    cmd = f"test -f {REBOOT}"
+    result = perform.execute(cmd)
     if result == 0:
-        command = f"cat {REBOOT}"
-        perform.execute(command)
+        cmd = f"cat {REBOOT}"
+        perform.execute(cmd)
+        cmd = f"test -f {PKGS}"
+        result = perform.execute(cmd)
+        if result == 0:
+            print("\nThe following packages necessitate the reboot:")
+            cmd = f"cat {PKGS} | perl -p -e 's|^|  |'"
+            perform.execute(cmd)
         print('To reboot use "sudo reboot"')
     else:
         print('A reboot is not required.')
